@@ -50,6 +50,26 @@
                 }
             },
 
+            'class' => {
+                type       => 'leaf',
+                value_type => 'uniline',
+                summary    => "Override implementation of configuration node",
+                description =>
+                "Perl class name used to override the default implementation of a configuration node. "
+                ."This Perl class must inherit L<Config::Model::Node>. Use with care.",
+                assert => {
+                    "1_load_class" => {
+                        code => 'not defined $_ or eval{Mouse::Util::load_class($_)}; not $@;',
+                        msg  => 'Error while loading $_ class ',
+                    },
+                    "2_class_inherit" => {
+                        code => 'not defined $_ or $_->isa("Config::Model::Node")',
+                        msg  => 'class $_ must inherit Config::Model::Node',
+                    }
+            },
+
+            },
+
             'element' => {
                 type       => 'hash',
                 level      => 'important',
